***********************************************************************************
*** Do file that creates the aggregate MIP data set used in "the 'Most Important Problem' Dataset (MIPD): A New Dataset on American Issue Importance"
*** 
*** Created: 6-17-15
*** Modified: 9-1-16
***
*** NOTES:
*** This uses the "MIPD--Release 1.0.dta" file to create the "MIPD Aggregate--CMPS.dta"
***********************************************************************************

clear
set mem 1200m

use "MIPD--Release 1.0.dta", clear

*******************************************************************************************
*** Drop those surveys with inappropriate question wordings
***
*** 3 = "facing your community today"
*** 17 = "most urgent problem"
*** 23 = "most important problem that you and your family face today"
*** 30 = "main problem"
*** 31 = "will be the most important problem...in the 21st Century"
*******************************************************************************************
drop if inlist(mipid, 3, 17, 23, 30, 31)

* For those surveys without an available weight, fill in -weight- with 1.
recode weight (.=1) if weightavail == 0

***********************************************************************************
*** Create the weighted percentages across subgroups.
***********************************************************************************
tempvar fp econ allelse
gen fp = cond(mip_marpor1 == ., ., cond(mip_marpor1 == 1, 1, 0))
gen econ = cond(mip_marpor1 == ., ., cond(mip_marpor1 == 4, 1, 0))
gen allelse = cond(mip_marpor1 == ., ., cond(inlist(mip_marpor1, 2, 3, 5, 6, 7, 8), 1, 0))

*** Create a temporary variable for the denominator
tempvar nonmiss denom
gen `nonmiss' = 1 if inrange(mip_marpor1, 1, 8)
bys studyid: egen `denom' = sum(weight * `nonmiss')

*** Generate the survey-specific weighted MIP percentages
qui foreach v of varlist fp econ allelse {
	tempvar `v'_num 
	bys studyid: egen ``v'_num' = sum(weight * `v')
	gen `v'_perc = 100 * (``v'_num' / `denom')
	lab var `v'_perc "Survey weighted (if available) % identifying `v' as MIP"
}

*** Generate the liberal/moderate/conservative MIP percentages
tempvar lib mod con
gen `lib' = cond(ideology == 1, 1, 0, .)
gen `mod' = cond(ideology == 2, 1, 0, .)
gen `con' = cond(ideology == 3, 1, 0, .)

qui foreach v of varlist fp econ allelse {
	foreach i in lib mod con {
		tempvar `v'_`i'_num `i'_denom `i'_nonmiss
		gen ``i'_nonmiss' = 1 if inrange(ideology, 1, 3) & !missing(mip_marpor1)
		bys studyid: egen ``i'_denom' = sum(weight * ``i'' * ``i'_nonmiss')
		bys studyid: egen ``v'_`i'_num' = sum(weight * `v' * ``i'')
		
		gen `v'_`i'_perc = 100 * (``v'_`i'_num' / ``i'_denom')
		lab var `v'_`i'_perc "Survey weighted (if available) % (`i') identifying `v' as MIP"
	}
}


*** Generate the Democrat, Independent, and Republican MIP percentages
tempvar dem ind rep
gen `dem' = cond(inrange(party_id, -3, -2), 1, 0, .)
gen `ind' = cond(inrange(party_id, -1, 1), 1, 0, .)
gen `rep' = cond(inrange(party_id, 2, 3), 1, 0, .)

qui foreach v of varlist fp econ allelse {
	foreach i in dem ind rep {
		tempvar `v'_`i'_num `i'_denom `i'_nonmiss
		gen ``i'_nonmiss' = 1 if inrange(party_id, -3, 3) & !missing(mip_marpor1)
		bys studyid: egen ``i'_denom' = sum(weight * ``i'' * ``i'_nonmiss')
		bys studyid: egen ``v'_`i'_num' = sum(weight * `v' * ``i'')
		gen `v'_`i'_perc = 100 * (``v'_`i'_num' / ``i'_denom')
		lab var `v'_`i'_perc "Survey weighted (if available) % (`i') identifying `v' as MIP"
	}
}

duplicates drop fw_start, force
keep studyid prev_ts next_ts fw* *_perc dem president short openended
compress

cap drop __*
sort fw_start

*** Generate a data set more appropriate for ggplot!
preserve
	keep studyid fw_start openended fp_perc - allelse_perc
	rename fp_perc perc1
	rename econ_perc perc2
	renam allelse_perc perc3
	
	reshape long perc, i(fw_start) j(problem)
	lab def problem_l 1 "Foreign Policy" 2 "Economy" 3 "All Else"
	lab val problem problem_l

	gen ideology = 4
	gen pid = 4
	
	tempfile all
	save `all', replace
restore

* Ideology
preserve
	keep studyid fw_start openended fp_lib_perc - allelse_con_perc

	rename fp_lib_perc lib_perc1
	rename fp_mod_perc mod_perc1
	rename fp_con_perc con_perc1
	rename econ_lib_perc lib_perc2
	rename econ_mod_perc mod_perc2
	rename econ_con_perc con_perc2
	rename allelse_lib_perc lib_perc3
	rename allelse_mod_perc mod_perc3
	rename allelse_con_perc con_perc3
	
	reshape long lib_perc mod_perc con_perc, i(fw_start) j(problem)
	
	rename lib_perc perc1
	rename mod_perc perc2
	rename con_perc perc3
	
	reshape long perc, i(fw_start problem) j(ideology)
	
	tempfile ideology
	save `ideology', replace
restore

* Partisan identification
preserve
	keep studyid fw_start openended fp_dem_perc - allelse_rep_perc

	rename fp_dem_perc dem_perc1
	rename fp_ind_perc ind_perc1
	rename fp_rep_perc rep_perc1
	rename econ_dem_perc dem_perc2
	rename econ_ind_perc ind_perc2
	rename econ_rep_perc rep_perc2
	rename allelse_dem_perc dem_perc3
	rename allelse_ind_perc ind_perc3
	rename allelse_rep_perc rep_perc3
	
	reshape long dem_perc ind_perc rep_perc, i(fw_start) j(problem)
	
	rename dem_perc perc1
	rename ind_perc perc2
	rename rep_perc perc3
	
	reshape long perc, i(fw_start problem) j(pid)
	
	tempfile pid
	save `pid', replace
restore

use `all', clear
append using `ideology'
append using `pid'

lab def ideology_l 1 "Liberal" 2 "Moderate" 3 "Conservative" 4 "Total"
lab def pid_l 1 "Democrat" 2 "Independent" 3 "Republican" 4 "Total"
lab val ideology ideology_l
lab val pid pid_l
lab val problem problem_l

gen fw_start2 = fw_start

save "MIPD Aggregate--CMPS.dta", replace

